<template>
  <el-dialog
    width="60%"
    title="客户订单"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      :bottomOffset="350"
      :paramArr="type"
      ref="customerOrderTable"
    >
      <template #toolbar></template>
    </ttable>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>

<script>
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { fetchListCustomerOrder } from '../../api/plan/customerorder'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: true
    }
  },
  data() {
    return {
      innerVisible: false,
      ajaxFun: fetchListCustomerOrder,
      type: [1],
      mpsRequirementsVisible: false,
      currentRow: null,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            width: '100px',
            prop: 'contractNo',
            label: '客户订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // {
          //  minWidth: '120',
          //  prop: 'customerNo',
          //  label: '客户编号',
          //  sort: true,
          //  isTrue: true,
          //  isSearch: true,
          //  searchInfoType: 'text'
          // },
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'coState',
            label: '客户订单状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getCustomerCoState,
            optList: () => {
              return this.coStateList
            }
          },
          // {
          //  minWidth: '120',
          //  prop: 'coLineNo',
          //  label: '行号',
          //  sort: true,
          //  isTrue: true,
          //  isSearch: true,
          //  searchInfoType: 'text'
          //  },
          {
            minWidth: '120',
            width: '100px',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'productName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'buyQtyDue',
            label: '销售数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'buyQtyDue',
            label: '已下发数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'otcUnit',
            label: '零件单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            width: '120',
            prop: 'deliveryDate',
            label: '交货时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
         // {
         //   minWidth: '200',
         //   width: '120',
         //   prop: 'plannedDeliveryDate',
         //   label: '计划交货时间',
         //   sort: true,
         //   isTrue: true,
         //   isSearch: true,
         //   searchInfoType: 'datetimerange',
         //   formatter: this.formatDutyDate
         // },
          {
            minWidth: '200',
            width: '120',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          }
        ],
        toolbar: [],
        operator: [],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      coStateList: [
        {
          value: '01plan',
          label: '待计划'
        },
        {
          value: '03planed',
          label: '已计划'
        },
        {
          value: '02planing',
          label: '计划中'
        },
        {
          value: '04complete',
          label: '已完成'
        }
      ]
    }
  },
  components: {
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  methods: {
    saveSelectRow() {
      this.$emit('handleSelectionChange', this.multipleSelection)
      this.innerVisible = false
    },
    getData() {
      this.$refs.customerOrderTable.getDataList()
    },
    formatDutyDate(row, column, cellValue) {
      if (cellValue) {
        const dutyDateList = /\d{4}-\d{1,2}-\d{1,2}/g.exec(cellValue)
        if (dutyDateList && dutyDateList.length > 0) {
          return dutyDateList[0]
        }
      }
      return ''
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    getCustomerCoState(row, column, cellValue) {
      this.coStateList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    }
  }
}
</script>
